.. _api_providers:

flameiq.providers — Plugin System
====================================

Base class
----------

.. automodule:: flameiq.providers.base
   :members:
   :special-members:

JSON Provider
-------------

.. automodule:: flameiq.providers.json_provider
   :members:

pytest-benchmark Provider
--------------------------

.. automodule:: flameiq.providers.pytest_provider
   :members:

Registry
--------

.. automodule:: flameiq.providers.registry
   :members:
